summaryrefslogtreecommitdiff
path: root/internal/version
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2026-04-14 11:23:26 +0300
committerPaul Buetow <paul@buetow.org>2026-04-14 11:23:26 +0300
commit17efa78e8e60b38e14430f2f89de005e946e8bf2 (patch)
treea8b8c76122b32ed570e2926fb266dfb563b136b0 /internal/version
parentc19666bd44b938ab2627b0c85935d3877c88b373 (diff)
fix: shadowing, version.Tag, prealloc LoadRecords (ask 54)
- CreateKey: avoid shadowing named return err on rand.Read - daemon Run: rename slog logger to slogLog vs stdlib log package - version: rename Version to Tag to avoid version.Version stutter - LoadRecords: COUNT(*) then make slice with capacity Made-with: Cursor
Diffstat (limited to 'internal/version')
-rw-r--r--internal/version/version.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/version/version.go b/internal/version/version.go
index a5f7f5b..db740bd 100644
--- a/internal/version/version.go
+++ b/internal/version/version.go
@@ -1,4 +1,4 @@
package version
-// Version is the application version.
-const Version = "0.2.4"
+// Tag is the application release version.
+const Tag = "0.2.4"